iam library

The Google Cloud client for the IAM Meta API.

Manages access control for Google Cloud Platform resources.

Classes

AuditConfig
Specifies the audit configuration for a service. The configuration determines which permission types are logged, and what identities, if any, are exempted from logging. An AuditConfig must have one or more AuditLogConfigs.
AuditConfigDelta
One delta entry for AuditConfig. Each individual change (only one exempted_member in each entry) to a AuditConfig will be a separate entry.
AuditConfigDelta_Action
The type of action performed on an audit configuration in a policy.
AuditLogConfig
Provides the configuration for logging a type of permissions. Example:
AuditLogConfig_LogType
The list of valid permission types for which logging can be configured. Admin writes are always logged, and are not configurable.
Binding
Associates members, or principals, with a role.
BindingDelta
One delta entry for Binding. Each individual change (only one member in each entry) to a binding will be a separate entry.
BindingDelta_Action
The type of action performed on a Binding in a policy.
GetIamPolicyRequest
Request message for GetIamPolicy method.
GetPolicyOptions
Encapsulates settings provided to GetIamPolicy.
IAMPolicy
API Overview
Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources.
PolicyDelta
The difference delta between two policies.
ResourcePolicyMember
Output-only policy member strings of a Google Cloud resource's built-in identity.
SetIamPolicyRequest
Request message for SetIamPolicy method.
TestIamPermissionsRequest
Request message for TestIamPermissions method.
TestIamPermissionsResponse
Response message for TestIamPermissions method.

Exceptions / Errors

BadGatewayException
Exception thrown when the server returns a "502 Bad Gateway" response.
BadRequestException
Exception thrown when the server returns a "400 Bad Request" response.
CancelledException
Exception thrown when the server returns a "499 Cancelled" response.
ConfigurationException
Exception thrown when a method is called without correct configuration.
ConflictException
Exception thrown when the server returns a "409 Conflict" response.
ForbiddenException
Exception thrown when the server returns a "403 Forbidden" response.
GatewayTimeoutException
Exception thrown when the server returns a "504 Gateway Timeout" response.
InternalServerErrorException
Exception thrown when the server returns a "500 Internal Server Error" response.
LengthRequiredException
Exception thrown when the server returns a "411 Length Required" response.
MethodNotAllowedException
Exception thrown when the server returns a "405 Method Not Allowed" response.
NotFoundException
Exception thrown when the server returns a "404 Not Found" response.
NotImplementedException
Exception thrown when the server returns a "501 Not Implemented" response.
NotModifiedException
Exception thrown when the server returns a "304 Not Modified" response.
PreconditionFailedException
Exception thrown when the server returns a "412 Precondition Failed" response.
RequestRangeNotSatisfiableException
Exception thrown when the server returns a "416 Request Range Not Satisfiable" response.
RequestTimeoutException
Exception thrown when the server returns a "408 Request Timeout" response.
ServiceException
Exception thrown when an API call fails.
ServiceUnavailableException
Exception thrown when the server returns a "503 Service Unavailable" response.
TooManyRequestsException
Exception thrown when the server returns a "429 Too Many Requests" response.
UnauthorizedException
Exception thrown when the server returns a "401 Unauthorized" response.