AuditConfigDelta class final

One delta entry for AuditConfig. Each individual change (only one exempted_member in each entry) to a AuditConfig will be a separate entry.

Constructors

AuditConfigDelta({AuditConfigDelta_Action action = AuditConfigDelta_Action.$default, String service = '', String exemptedMember = '', String logType = ''})
AuditConfigDelta.fromJson(Object? j)
factory

Properties

action → AuditConfigDelta_Action
The action that was performed on an audit configuration in a policy. Required
final
exemptedMember → String
A single identity that is exempted from "data access" audit logging for the service specified above. Follows the same format of Binding.members.
final
hashCode → int
The hash code for this object.
no setterinherited
logType → String
Specifies the log_type that was be enabled. ADMIN_ACTIVITY is always enabled, and cannot be configured. Required
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → String
Specifies a service that was configured for Cloud Audit Logging. For example, storage.googleapis.com, cloudsql.googleapis.com. allServices is a special value that covers all services. Required
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String