AuditConfigDelta_Action class final

The type of action performed on an audit configuration in a policy.

Constructors

AuditConfigDelta_Action(String value)
const
AuditConfigDelta_Action.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const AuditConfigDelta_Action
The default value for AuditConfigDelta_Action.
actionUnspecified → const AuditConfigDelta_Action
Unspecified.
add → const AuditConfigDelta_Action
Addition of an audit configuration.
remove → const AuditConfigDelta_Action
Removal of an audit configuration.