Binding class final

Associates members, or principals, with a role.

Constructors

Binding({String role = '', List<String> members = const [], Expr? condition})
Binding.fromJson(Object? j)
factory

Properties

condition → Expr?
The condition that is associated with this binding.
final
hashCode → int
The hash code for this object.
no setterinherited
members → List<String>
Specifies the principals requesting access for a Google Cloud resource. members can have the following values:
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
role → String
Role that is assigned to the list of members, or principals. For example, roles/viewer, roles/editor, or roles/owner.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String