BindingDelta class final

One delta entry for Binding. Each individual change (only one member in each entry) to a binding will be a separate entry.

Constructors

BindingDelta({BindingDelta_Action action = BindingDelta_Action.$default, String role = '', String member = '', Expr? condition})
BindingDelta.fromJson(Object? j)
factory

Properties

action → BindingDelta_Action
The action that was performed on a Binding. Required
final
condition → Expr?
The condition that is associated with this binding.
final
hashCode → int
The hash code for this object.
no setterinherited
member → String
A single identity requesting access for a Google Cloud resource. Follows the same format of Binding.members. Required
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
role → String
Role that is assigned to members. For example, roles/viewer, roles/editor, or roles/owner. Required
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String