ResourcePolicyMember class final

Output-only policy member strings of a Google Cloud resource's built-in identity.

Constructors

ResourcePolicyMember({String iamPolicyNamePrincipal = '', String iamPolicyUidPrincipal = ''})
ResourcePolicyMember.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iamPolicyNamePrincipal → String
IAM policy binding member referring to a Google Cloud resource by user-assigned name (https://google.aip.dev/122). If a resource is deleted and recreated with the same name, the binding will be applicable to the new resource.
final
iamPolicyUidPrincipal → String
IAM policy binding member referring to a Google Cloud resource by system-assigned unique identifier (https://google.aip.dev/148#uid). If a resource is deleted and recreated with the same name, the binding will not be applicable to the new resource
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String