SetIamPolicyRequest class final

Request message for SetIamPolicy method.

Constructors

SetIamPolicyRequest({required String resource, required Policy? policy, FieldMask? updateMask})
SetIamPolicyRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
policy → Policy?
REQUIRED: The complete policy to be applied to the resource. The size of the policy is limited to a few 10s of KB. An empty policy is a valid policy but certain Cloud Platform services (such as Projects) might reject them.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resource → String
REQUIRED: The resource for which the policy is being specified. See the operation documentation for the appropriate value for this field.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask → FieldMask?
OPTIONAL: A FieldMask specifying which fields of the policy to modify. Only the fields in the mask will be modified. If no mask is provided, the following default mask is used:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String