getIamPolicy method

  1. @override
Future<Policy> getIamPolicy(
  1. GetIamPolicyRequest request
)
override

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Policy> getIamPolicy(GetIamPolicyRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getIamPolicy case final getIamPolicy?) {
    return getIamPolicy(request);
  }
  throw UnsupportedError('getIamPolicy');
}