setIamPolicy method

  1. @override
Future<Policy> setIamPolicy(
  1. SetIamPolicyRequest request
)
override

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Policy> setIamPolicy(SetIamPolicyRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setIamPolicy case final setIamPolicy?) {
    return setIamPolicy(request);
  }
  throw UnsupportedError('setIamPolicy');
}