FakeIAMPolicy class base
Testing fake for IAMPolicy.
- Implemented types
Constructors
-
FakeIAMPolicy({Future<
Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?})
Properties
Methods
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
getIamPolicy(
GetIamPolicyRequest request) → Future< Policy> -
Gets the access control policy for a resource.
Returns an empty policy if the resource exists and does not have a policy
set.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRequest request) → Future< Policy> -
Sets the access control policy on the specified resource. Replaces any
existing policy.
override
-
testIamPermissions(
TestIamPermissionsRequest request) → Future< TestIamPermissionsResponse> -
Returns permissions that a caller has on the specified resource.
If the resource does not exist, this will return an empty set of
permissions, not a
NOT_FOUNDerror.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited